import fetch from 'node-fetch';

// Function to handle form submission and interact with Listmonk
export async function submitToListmonk(req, res) {
    const { name, email, message } = req.body;

    const listmonkUrl = process.env.LISTMONK_URL;
    const listmonkUsername = process.env.LISTMONK_USERNAME;
    const listmonkPassword = process.env.LISTMONK_PASSWORD;
    const campaignId = process.env.PRESET_CAMPAIGN_ID;
    const listmonkBaseUrl = process.env.LISTMONK_BASE_URL;
    const listId = parseInt(process.env.LIST_ID, 10);

    // Encode username and password as base64
    const auth = Buffer.from(`${listmonkUsername}:${listmonkPassword}`).toString('base64');

    console.log(`Sending request to Listmonk with URL: ${listmonkUrl}`);

    const payload = {
        email,
        name,
        lists: [listId],
        fields: { message }
    };

    console.log('Sending request to Listmonk with payload:', payload);

    async function fetchWithRetry(url, options, retries = 3) {
        for (let i = 0; i < retries; i++) {
          console.log(`Attempt ${i + 1} sending request to ${url}`);
          try {
            const res = await fetch(url, options);
            if (!res.ok) throw new Error(`HTTP ${res.status}`);
            return res;
          } catch (err) {
            console.log(`Attempt ${i + 1} failed: ${err}`);
            if (i === retries - 1) throw err;
            await new Promise(resolve => setTimeout(resolve, 500));
          }
        }
      }
      
    try {
        // Add subscriber
        const response = await fetchWithRetry(listmonkUrl, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Basic ${auth}`
            },
            body: JSON.stringify(payload),
        },3);

        if (!response.ok) {
            const errorBody = await response.text();
            throw new Error(`Listmonk API error: ${response.statusText}. Response body: ${errorBody}`);
        }

        const result = await response.json();
        console.log('Subscriber added successfully:', result);

        // Update campaign status to "scheduled"
        const campaignStatusUrl = `${listmonkBaseUrl}/campaigns/${campaignId}/status`;
        const scheduleTime = new Date(Date.now() + 5 * 60 * 1000).toISOString(); // Schedule 5 minutes from now
        const statusPayload = {
            status: 'scheduled',
            schedule: scheduleTime,
        };

        console.log('Updating campaign status using URL:', campaignStatusUrl);
        console.log('Campaign status payload:', statusPayload);

        try {
            const statusResponse = await fetch(campaignStatusUrl, {
                method: 'PUT',
                headers: {
                    'Content-Type': 'application/json',
                    'Authorization': `Basic ${auth}`,
                },
                body: JSON.stringify(statusPayload),
            });

            if (!statusResponse.ok) {
                const errorBody = await statusResponse.text();
                console.error('Response from Listmonk:', errorBody);
                throw new Error(`Listmonk API error (Update Campaign Status): ${statusResponse.statusText}. Response body: ${errorBody}`);
            }

            const statusResult = await statusResponse.json();
            console.log('Campaign status updated successfully:', statusResult);
        } catch (error) {
            console.error('Error updating campaign status:', error);
        }

        const statusResult = await statusResponse.json();
        console.log('Campaign status updated successfully:', statusResult);

        // Send the campaign
        const campaignSendUrl = `${listmonkBaseUrl}/campaigns/${campaignId}/send`;
        console.log('Sending campaign using URL:', campaignSendUrl);

        const campaignResponse = await fetch(campaignSendUrl, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Basic ${auth}`,
            },
        });

        if (!campaignResponse.ok) {
            const errorBody = await campaignResponse.text();
            throw new Error(`Listmonk API error (Send Campaign): ${campaignResponse.statusText}. Response body: ${errorBody}`);
        }

        const campaignResult = await campaignResponse.json();
        console.log('Campaign sent successfully:', campaignResult);

        res.status(200).json({ message: 'Subscription successful!', result });
    } catch (error) {
        console.error('Error submitting to Listmonk:', error);
        res.status(500).json({ message: 'Failed to submit to Listmonk', error: error.message });
    }
}
